"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BidModifierSimulationPointList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POINTS_FIELD_NUMBER: builtins.int
    @property
    def points(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___BidModifierSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing.Optional[
            typing.Iterable[global___BidModifierSimulationPoint]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["points", b"points"]
    ) -> None: ...

global___BidModifierSimulationPointList = BidModifierSimulationPointList

class CpcBidSimulationPointList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POINTS_FIELD_NUMBER: builtins.int
    @property
    def points(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___CpcBidSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing.Optional[typing.Iterable[global___CpcBidSimulationPoint]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["points", b"points"]
    ) -> None: ...

global___CpcBidSimulationPointList = CpcBidSimulationPointList

class CpvBidSimulationPointList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POINTS_FIELD_NUMBER: builtins.int
    @property
    def points(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___CpvBidSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing.Optional[typing.Iterable[global___CpvBidSimulationPoint]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["points", b"points"]
    ) -> None: ...

global___CpvBidSimulationPointList = CpvBidSimulationPointList

class TargetCpaSimulationPointList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POINTS_FIELD_NUMBER: builtins.int
    @property
    def points(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___TargetCpaSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing.Optional[
            typing.Iterable[global___TargetCpaSimulationPoint]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["points", b"points"]
    ) -> None: ...

global___TargetCpaSimulationPointList = TargetCpaSimulationPointList

class TargetRoasSimulationPointList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POINTS_FIELD_NUMBER: builtins.int
    @property
    def points(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___TargetRoasSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing.Optional[
            typing.Iterable[global___TargetRoasSimulationPoint]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["points", b"points"]
    ) -> None: ...

global___TargetRoasSimulationPointList = TargetRoasSimulationPointList

class BidModifierSimulationPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BID_MODIFIER_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    TOP_SLOT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    PARENT_BIDDABLE_CONVERSIONS_FIELD_NUMBER: builtins.int
    PARENT_BIDDABLE_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    PARENT_CLICKS_FIELD_NUMBER: builtins.int
    PARENT_COST_MICROS_FIELD_NUMBER: builtins.int
    PARENT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    PARENT_TOP_SLOT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    PARENT_REQUIRED_BUDGET_MICROS_FIELD_NUMBER: builtins.int
    @property
    def bid_modifier(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def biddable_conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def biddable_conversions_value(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def cost_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def top_slot_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def parent_biddable_conversions(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def parent_biddable_conversions_value(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def parent_clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def parent_cost_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def parent_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def parent_top_slot_impressions(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def parent_required_budget_micros(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        bid_modifier: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        biddable_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        biddable_conversions_value: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        cost_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        impressions: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        top_slot_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        parent_biddable_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        parent_biddable_conversions_value: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        parent_clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        parent_cost_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        parent_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        parent_top_slot_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        parent_required_budget_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "bid_modifier",
            b"bid_modifier",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "parent_biddable_conversions",
            b"parent_biddable_conversions",
            "parent_biddable_conversions_value",
            b"parent_biddable_conversions_value",
            "parent_clicks",
            b"parent_clicks",
            "parent_cost_micros",
            b"parent_cost_micros",
            "parent_impressions",
            b"parent_impressions",
            "parent_required_budget_micros",
            b"parent_required_budget_micros",
            "parent_top_slot_impressions",
            b"parent_top_slot_impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "bid_modifier",
            b"bid_modifier",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "parent_biddable_conversions",
            b"parent_biddable_conversions",
            "parent_biddable_conversions_value",
            b"parent_biddable_conversions_value",
            "parent_clicks",
            b"parent_clicks",
            "parent_cost_micros",
            b"parent_cost_micros",
            "parent_impressions",
            b"parent_impressions",
            "parent_required_budget_micros",
            b"parent_required_budget_micros",
            "parent_top_slot_impressions",
            b"parent_top_slot_impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...

global___BidModifierSimulationPoint = BidModifierSimulationPoint

class CpcBidSimulationPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CPC_BID_MICROS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    TOP_SLOT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    @property
    def cpc_bid_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def biddable_conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def biddable_conversions_value(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def cost_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def top_slot_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        cpc_bid_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        biddable_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        biddable_conversions_value: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        cost_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        impressions: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        top_slot_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "impressions",
            b"impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "impressions",
            b"impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...

global___CpcBidSimulationPoint = CpcBidSimulationPoint

class CpvBidSimulationPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CPV_BID_MICROS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    VIEWS_FIELD_NUMBER: builtins.int
    @property
    def cpv_bid_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def cost_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def views(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        cpv_bid_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        cost_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        impressions: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        views: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "cost_micros",
            b"cost_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "impressions",
            b"impressions",
            "views",
            b"views",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "cost_micros",
            b"cost_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "impressions",
            b"impressions",
            "views",
            b"views",
        ],
    ) -> None: ...

global___CpvBidSimulationPoint = CpvBidSimulationPoint

class TargetCpaSimulationPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TARGET_CPA_MICROS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    TOP_SLOT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    @property
    def target_cpa_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def biddable_conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def biddable_conversions_value(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def cost_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def top_slot_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        target_cpa_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        biddable_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        biddable_conversions_value: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        cost_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        impressions: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        top_slot_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_cpa_micros",
            b"target_cpa_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_cpa_micros",
            b"target_cpa_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...

global___TargetCpaSimulationPoint = TargetCpaSimulationPoint

class TargetRoasSimulationPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TARGET_ROAS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    TOP_SLOT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    @property
    def target_roas(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def biddable_conversions(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def biddable_conversions_value(
        self,
    ) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def clicks(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def cost_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def top_slot_impressions(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        target_roas: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
        biddable_conversions: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        biddable_conversions_value: typing.Optional[
            google.protobuf.wrappers_pb2.DoubleValue
        ] = ...,
        clicks: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        cost_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        impressions: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        top_slot_impressions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_roas",
            b"target_roas",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_roas",
            b"target_roas",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...

global___TargetRoasSimulationPoint = TargetRoasSimulationPoint



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.criteria_pb2
import google.ads.google_ads.v5.proto.enums.campaign_criterion_status_pb2
import google.ads.google_ads.v5.proto.enums.criterion_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignCriterion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CAMPAIGN_FIELD_NUMBER: builtins.int
    CRITERION_ID_FIELD_NUMBER: builtins.int
    BID_MODIFIER_FIELD_NUMBER: builtins.int
    NEGATIVE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    PLACEMENT_FIELD_NUMBER: builtins.int
    MOBILE_APP_CATEGORY_FIELD_NUMBER: builtins.int
    MOBILE_APPLICATION_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AD_SCHEDULE_FIELD_NUMBER: builtins.int
    AGE_RANGE_FIELD_NUMBER: builtins.int
    GENDER_FIELD_NUMBER: builtins.int
    INCOME_RANGE_FIELD_NUMBER: builtins.int
    PARENTAL_STATUS_FIELD_NUMBER: builtins.int
    USER_LIST_FIELD_NUMBER: builtins.int
    YOUTUBE_VIDEO_FIELD_NUMBER: builtins.int
    YOUTUBE_CHANNEL_FIELD_NUMBER: builtins.int
    PROXIMITY_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    LISTING_SCOPE_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    IP_BLOCK_FIELD_NUMBER: builtins.int
    CONTENT_LABEL_FIELD_NUMBER: builtins.int
    CARRIER_FIELD_NUMBER: builtins.int
    USER_INTEREST_FIELD_NUMBER: builtins.int
    WEBPAGE_FIELD_NUMBER: builtins.int
    OPERATING_SYSTEM_VERSION_FIELD_NUMBER: builtins.int
    MOBILE_DEVICE_FIELD_NUMBER: builtins.int
    LOCATION_GROUP_FIELD_NUMBER: builtins.int
    CUSTOM_AFFINITY_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    campaign: typing.Text = ...
    criterion_id: builtins.int = ...
    bid_modifier: builtins.float = ...
    negative: builtins.bool = ...
    type: google.ads.google_ads.v5.proto.enums.criterion_type_pb2.CriterionTypeEnum.CriterionType.V = (
        ...
    )
    status: google.ads.google_ads.v5.proto.enums.campaign_criterion_status_pb2.CampaignCriterionStatusEnum.CampaignCriterionStatus.V = (
        ...
    )
    @property
    def keyword(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.KeywordInfo: ...
    @property
    def placement(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.PlacementInfo: ...
    @property
    def mobile_app_category(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.MobileAppCategoryInfo: ...
    @property
    def mobile_application(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.MobileApplicationInfo: ...
    @property
    def location(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.LocationInfo: ...
    @property
    def device(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.DeviceInfo: ...
    @property
    def ad_schedule(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.AdScheduleInfo: ...
    @property
    def age_range(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.AgeRangeInfo: ...
    @property
    def gender(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.GenderInfo: ...
    @property
    def income_range(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.IncomeRangeInfo: ...
    @property
    def parental_status(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.ParentalStatusInfo: ...
    @property
    def user_list(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.UserListInfo: ...
    @property
    def youtube_video(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.YouTubeVideoInfo: ...
    @property
    def youtube_channel(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.YouTubeChannelInfo: ...
    @property
    def proximity(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.ProximityInfo: ...
    @property
    def topic(self) -> google.ads.google_ads.v5.proto.common.criteria_pb2.TopicInfo: ...
    @property
    def listing_scope(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.ListingScopeInfo: ...
    @property
    def language(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.LanguageInfo: ...
    @property
    def ip_block(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.IpBlockInfo: ...
    @property
    def content_label(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.ContentLabelInfo: ...
    @property
    def carrier(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.CarrierInfo: ...
    @property
    def user_interest(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.UserInterestInfo: ...
    @property
    def webpage(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.WebpageInfo: ...
    @property
    def operating_system_version(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.OperatingSystemVersionInfo: ...
    @property
    def mobile_device(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.MobileDeviceInfo: ...
    @property
    def location_group(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.LocationGroupInfo: ...
    @property
    def custom_affinity(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.CustomAffinityInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        campaign: typing.Text = ...,
        criterion_id: builtins.int = ...,
        bid_modifier: builtins.float = ...,
        negative: builtins.bool = ...,
        type: google.ads.google_ads.v5.proto.enums.criterion_type_pb2.CriterionTypeEnum.CriterionType.V = ...,
        status: google.ads.google_ads.v5.proto.enums.campaign_criterion_status_pb2.CampaignCriterionStatusEnum.CampaignCriterionStatus.V = ...,
        keyword: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.KeywordInfo
        ] = ...,
        placement: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.PlacementInfo
        ] = ...,
        mobile_app_category: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.MobileAppCategoryInfo
        ] = ...,
        mobile_application: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.MobileApplicationInfo
        ] = ...,
        location: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.LocationInfo
        ] = ...,
        device: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.DeviceInfo
        ] = ...,
        ad_schedule: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.AdScheduleInfo
        ] = ...,
        age_range: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.AgeRangeInfo
        ] = ...,
        gender: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.GenderInfo
        ] = ...,
        income_range: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.IncomeRangeInfo
        ] = ...,
        parental_status: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.ParentalStatusInfo
        ] = ...,
        user_list: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.UserListInfo
        ] = ...,
        youtube_video: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.YouTubeVideoInfo
        ] = ...,
        youtube_channel: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.YouTubeChannelInfo
        ] = ...,
        proximity: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.ProximityInfo
        ] = ...,
        topic: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.TopicInfo
        ] = ...,
        listing_scope: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.ListingScopeInfo
        ] = ...,
        language: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.LanguageInfo
        ] = ...,
        ip_block: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.IpBlockInfo
        ] = ...,
        content_label: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.ContentLabelInfo
        ] = ...,
        carrier: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.CarrierInfo
        ] = ...,
        user_interest: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.UserInterestInfo
        ] = ...,
        webpage: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.WebpageInfo
        ] = ...,
        operating_system_version: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.OperatingSystemVersionInfo
        ] = ...,
        mobile_device: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.MobileDeviceInfo
        ] = ...,
        location_group: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.LocationGroupInfo
        ] = ...,
        custom_affinity: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.CustomAffinityInfo
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_bid_modifier",
            b"_bid_modifier",
            "_campaign",
            b"_campaign",
            "_criterion_id",
            b"_criterion_id",
            "_negative",
            b"_negative",
            "ad_schedule",
            b"ad_schedule",
            "age_range",
            b"age_range",
            "bid_modifier",
            b"bid_modifier",
            "campaign",
            b"campaign",
            "carrier",
            b"carrier",
            "content_label",
            b"content_label",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "custom_affinity",
            b"custom_affinity",
            "device",
            b"device",
            "gender",
            b"gender",
            "income_range",
            b"income_range",
            "ip_block",
            b"ip_block",
            "keyword",
            b"keyword",
            "language",
            b"language",
            "listing_scope",
            b"listing_scope",
            "location",
            b"location",
            "location_group",
            b"location_group",
            "mobile_app_category",
            b"mobile_app_category",
            "mobile_application",
            b"mobile_application",
            "mobile_device",
            b"mobile_device",
            "negative",
            b"negative",
            "operating_system_version",
            b"operating_system_version",
            "parental_status",
            b"parental_status",
            "placement",
            b"placement",
            "proximity",
            b"proximity",
            "topic",
            b"topic",
            "user_interest",
            b"user_interest",
            "user_list",
            b"user_list",
            "webpage",
            b"webpage",
            "youtube_channel",
            b"youtube_channel",
            "youtube_video",
            b"youtube_video",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_bid_modifier",
            b"_bid_modifier",
            "_campaign",
            b"_campaign",
            "_criterion_id",
            b"_criterion_id",
            "_negative",
            b"_negative",
            "ad_schedule",
            b"ad_schedule",
            "age_range",
            b"age_range",
            "bid_modifier",
            b"bid_modifier",
            "campaign",
            b"campaign",
            "carrier",
            b"carrier",
            "content_label",
            b"content_label",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "custom_affinity",
            b"custom_affinity",
            "device",
            b"device",
            "gender",
            b"gender",
            "income_range",
            b"income_range",
            "ip_block",
            b"ip_block",
            "keyword",
            b"keyword",
            "language",
            b"language",
            "listing_scope",
            b"listing_scope",
            "location",
            b"location",
            "location_group",
            b"location_group",
            "mobile_app_category",
            b"mobile_app_category",
            "mobile_application",
            b"mobile_application",
            "mobile_device",
            b"mobile_device",
            "negative",
            b"negative",
            "operating_system_version",
            b"operating_system_version",
            "parental_status",
            b"parental_status",
            "placement",
            b"placement",
            "proximity",
            b"proximity",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "topic",
            b"topic",
            "type",
            b"type",
            "user_interest",
            b"user_interest",
            "user_list",
            b"user_list",
            "webpage",
            b"webpage",
            "youtube_channel",
            b"youtube_channel",
            "youtube_video",
            b"youtube_video",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_bid_modifier", b"_bid_modifier"]
    ) -> typing_extensions.Literal["bid_modifier"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_campaign", b"_campaign"]
    ) -> typing_extensions.Literal["campaign"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_criterion_id", b"_criterion_id"]
    ) -> typing_extensions.Literal["criterion_id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_negative", b"_negative"]
    ) -> typing_extensions.Literal["negative"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["criterion", b"criterion"]
    ) -> typing_extensions.Literal[
        "keyword",
        "placement",
        "mobile_app_category",
        "mobile_application",
        "location",
        "device",
        "ad_schedule",
        "age_range",
        "gender",
        "income_range",
        "parental_status",
        "user_list",
        "youtube_video",
        "youtube_channel",
        "proximity",
        "topic",
        "listing_scope",
        "language",
        "ip_block",
        "content_label",
        "carrier",
        "user_interest",
        "webpage",
        "operating_system_version",
        "mobile_device",
        "location_group",
        "custom_affinity",
    ]: ...

global___CampaignCriterion = CampaignCriterion



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DataDrivenModelStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _DataDrivenModelStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            DataDrivenModelStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(0)
        UNKNOWN = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(1)
        AVAILABLE = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(2)
        STALE = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(3)
        EXPIRED = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(4)
        NEVER_GENERATED = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(5)
    class DataDrivenModelStatus(metaclass=_DataDrivenModelStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(0)
    UNKNOWN = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(1)
    AVAILABLE = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(2)
    STALE = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(3)
    EXPIRED = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(4)
    NEVER_GENERATED = DataDrivenModelStatusEnum.DataDrivenModelStatus.V(5)
    def __init__(
        self,
    ) -> None: ...

global___DataDrivenModelStatusEnum = DataDrivenModelStatusEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.budget_delivery_method_pb2
import google.ads.google_ads.v4.proto.enums.budget_period_pb2
import google.ads.google_ads.v4.proto.enums.budget_status_pb2
import google.ads.google_ads.v4.proto.enums.budget_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignBudget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    TOTAL_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DELIVERY_METHOD_FIELD_NUMBER: builtins.int
    EXPLICITLY_SHARED_FIELD_NUMBER: builtins.int
    REFERENCE_COUNT_FIELD_NUMBER: builtins.int
    HAS_RECOMMENDED_BUDGET_FIELD_NUMBER: builtins.int
    RECOMMENDED_BUDGET_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    RECOMMENDED_BUDGET_ESTIMATED_CHANGE_WEEKLY_CLICKS_FIELD_NUMBER: builtins.int
    RECOMMENDED_BUDGET_ESTIMATED_CHANGE_WEEKLY_COST_MICROS_FIELD_NUMBER: builtins.int
    RECOMMENDED_BUDGET_ESTIMATED_CHANGE_WEEKLY_INTERACTIONS_FIELD_NUMBER: builtins.int
    RECOMMENDED_BUDGET_ESTIMATED_CHANGE_WEEKLY_VIEWS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    status: google.ads.google_ads.v4.proto.enums.budget_status_pb2.BudgetStatusEnum.BudgetStatus.V = (
        ...
    )
    delivery_method: google.ads.google_ads.v4.proto.enums.budget_delivery_method_pb2.BudgetDeliveryMethodEnum.BudgetDeliveryMethod.V = (
        ...
    )
    period: google.ads.google_ads.v4.proto.enums.budget_period_pb2.BudgetPeriodEnum.BudgetPeriod.V = (
        ...
    )
    type: google.ads.google_ads.v4.proto.enums.budget_type_pb2.BudgetTypeEnum.BudgetType.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def amount_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def total_amount_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def explicitly_shared(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def reference_count(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def has_recommended_budget(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def recommended_budget_amount_micros(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def recommended_budget_estimated_change_weekly_clicks(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def recommended_budget_estimated_change_weekly_cost_micros(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def recommended_budget_estimated_change_weekly_interactions(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def recommended_budget_estimated_change_weekly_views(
        self,
    ) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        amount_micros: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        total_amount_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        status: google.ads.google_ads.v4.proto.enums.budget_status_pb2.BudgetStatusEnum.BudgetStatus.V = ...,
        delivery_method: google.ads.google_ads.v4.proto.enums.budget_delivery_method_pb2.BudgetDeliveryMethodEnum.BudgetDeliveryMethod.V = ...,
        explicitly_shared: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
        reference_count: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        has_recommended_budget: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
        recommended_budget_amount_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        period: google.ads.google_ads.v4.proto.enums.budget_period_pb2.BudgetPeriodEnum.BudgetPeriod.V = ...,
        recommended_budget_estimated_change_weekly_clicks: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        recommended_budget_estimated_change_weekly_cost_micros: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        recommended_budget_estimated_change_weekly_interactions: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        recommended_budget_estimated_change_weekly_views: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        type: google.ads.google_ads.v4.proto.enums.budget_type_pb2.BudgetTypeEnum.BudgetType.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "amount_micros",
            b"amount_micros",
            "explicitly_shared",
            b"explicitly_shared",
            "has_recommended_budget",
            b"has_recommended_budget",
            "id",
            b"id",
            "name",
            b"name",
            "recommended_budget_amount_micros",
            b"recommended_budget_amount_micros",
            "recommended_budget_estimated_change_weekly_clicks",
            b"recommended_budget_estimated_change_weekly_clicks",
            "recommended_budget_estimated_change_weekly_cost_micros",
            b"recommended_budget_estimated_change_weekly_cost_micros",
            "recommended_budget_estimated_change_weekly_interactions",
            b"recommended_budget_estimated_change_weekly_interactions",
            "recommended_budget_estimated_change_weekly_views",
            b"recommended_budget_estimated_change_weekly_views",
            "reference_count",
            b"reference_count",
            "total_amount_micros",
            b"total_amount_micros",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "amount_micros",
            b"amount_micros",
            "delivery_method",
            b"delivery_method",
            "explicitly_shared",
            b"explicitly_shared",
            "has_recommended_budget",
            b"has_recommended_budget",
            "id",
            b"id",
            "name",
            b"name",
            "period",
            b"period",
            "recommended_budget_amount_micros",
            b"recommended_budget_amount_micros",
            "recommended_budget_estimated_change_weekly_clicks",
            b"recommended_budget_estimated_change_weekly_clicks",
            "recommended_budget_estimated_change_weekly_cost_micros",
            b"recommended_budget_estimated_change_weekly_cost_micros",
            "recommended_budget_estimated_change_weekly_interactions",
            b"recommended_budget_estimated_change_weekly_interactions",
            "recommended_budget_estimated_change_weekly_views",
            b"recommended_budget_estimated_change_weekly_views",
            "reference_count",
            b"reference_count",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "total_amount_micros",
            b"total_amount_micros",
            "type",
            b"type",
        ],
    ) -> None: ...

global___CampaignBudget = CampaignBudget



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class JobPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _JobPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            JobPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = JobPlaceholderFieldEnum.JobPlaceholderField.V(0)
        UNKNOWN = JobPlaceholderFieldEnum.JobPlaceholderField.V(1)
        JOB_ID = JobPlaceholderFieldEnum.JobPlaceholderField.V(2)
        LOCATION_ID = JobPlaceholderFieldEnum.JobPlaceholderField.V(3)
        TITLE = JobPlaceholderFieldEnum.JobPlaceholderField.V(4)
        SUBTITLE = JobPlaceholderFieldEnum.JobPlaceholderField.V(5)
        DESCRIPTION = JobPlaceholderFieldEnum.JobPlaceholderField.V(6)
        IMAGE_URL = JobPlaceholderFieldEnum.JobPlaceholderField.V(7)
        CATEGORY = JobPlaceholderFieldEnum.JobPlaceholderField.V(8)
        CONTEXTUAL_KEYWORDS = JobPlaceholderFieldEnum.JobPlaceholderField.V(9)
        ADDRESS = JobPlaceholderFieldEnum.JobPlaceholderField.V(10)
        SALARY = JobPlaceholderFieldEnum.JobPlaceholderField.V(11)
        FINAL_URLS = JobPlaceholderFieldEnum.JobPlaceholderField.V(12)
        FINAL_MOBILE_URLS = JobPlaceholderFieldEnum.JobPlaceholderField.V(14)
        TRACKING_URL = JobPlaceholderFieldEnum.JobPlaceholderField.V(15)
        ANDROID_APP_LINK = JobPlaceholderFieldEnum.JobPlaceholderField.V(16)
        SIMILAR_JOB_IDS = JobPlaceholderFieldEnum.JobPlaceholderField.V(17)
        IOS_APP_LINK = JobPlaceholderFieldEnum.JobPlaceholderField.V(18)
        IOS_APP_STORE_ID = JobPlaceholderFieldEnum.JobPlaceholderField.V(19)
    class JobPlaceholderField(metaclass=_JobPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = JobPlaceholderFieldEnum.JobPlaceholderField.V(0)
    UNKNOWN = JobPlaceholderFieldEnum.JobPlaceholderField.V(1)
    JOB_ID = JobPlaceholderFieldEnum.JobPlaceholderField.V(2)
    LOCATION_ID = JobPlaceholderFieldEnum.JobPlaceholderField.V(3)
    TITLE = JobPlaceholderFieldEnum.JobPlaceholderField.V(4)
    SUBTITLE = JobPlaceholderFieldEnum.JobPlaceholderField.V(5)
    DESCRIPTION = JobPlaceholderFieldEnum.JobPlaceholderField.V(6)
    IMAGE_URL = JobPlaceholderFieldEnum.JobPlaceholderField.V(7)
    CATEGORY = JobPlaceholderFieldEnum.JobPlaceholderField.V(8)
    CONTEXTUAL_KEYWORDS = JobPlaceholderFieldEnum.JobPlaceholderField.V(9)
    ADDRESS = JobPlaceholderFieldEnum.JobPlaceholderField.V(10)
    SALARY = JobPlaceholderFieldEnum.JobPlaceholderField.V(11)
    FINAL_URLS = JobPlaceholderFieldEnum.JobPlaceholderField.V(12)
    FINAL_MOBILE_URLS = JobPlaceholderFieldEnum.JobPlaceholderField.V(14)
    TRACKING_URL = JobPlaceholderFieldEnum.JobPlaceholderField.V(15)
    ANDROID_APP_LINK = JobPlaceholderFieldEnum.JobPlaceholderField.V(16)
    SIMILAR_JOB_IDS = JobPlaceholderFieldEnum.JobPlaceholderField.V(17)
    IOS_APP_LINK = JobPlaceholderFieldEnum.JobPlaceholderField.V(18)
    IOS_APP_STORE_ID = JobPlaceholderFieldEnum.JobPlaceholderField.V(19)
    def __init__(
        self,
    ) -> None: ...

global___JobPlaceholderFieldEnum = JobPlaceholderFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class LanguageConstant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TARGETABLE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def targetable(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        targetable: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "code", b"code", "id", b"id", "name", b"name", "targetable", b"targetable"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "code",
            b"code",
            "id",
            b"id",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "targetable",
            b"targetable",
        ],
    ) -> None: ...

global___LanguageConstant = LanguageConstant



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.ad_asset_pb2
import google.ads.google_ads.v6.proto.enums.call_conversion_reporting_state_pb2
import google.ads.google_ads.v6.proto.enums.display_ad_format_setting_pb2
import google.ads.google_ads.v6.proto.enums.display_upload_product_type_pb2
import google.ads.google_ads.v6.proto.enums.legacy_app_install_ad_app_store_pb2
import google.ads.google_ads.v6.proto.enums.mime_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TextAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINE_FIELD_NUMBER: builtins.int
    DESCRIPTION1_FIELD_NUMBER: builtins.int
    DESCRIPTION2_FIELD_NUMBER: builtins.int
    headline: typing.Text = ...
    description1: typing.Text = ...
    description2: typing.Text = ...
    def __init__(
        self,
        *,
        headline: typing.Text = ...,
        description1: typing.Text = ...,
        description2: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description1", b"_description1"]
    ) -> typing_extensions.Literal["description1"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description2", b"_description2"]
    ) -> typing_extensions.Literal["description2"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_headline", b"_headline"]
    ) -> typing_extensions.Literal["headline"]: ...

global___TextAdInfo = TextAdInfo

class ExpandedTextAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINE_PART1_FIELD_NUMBER: builtins.int
    HEADLINE_PART2_FIELD_NUMBER: builtins.int
    HEADLINE_PART3_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DESCRIPTION2_FIELD_NUMBER: builtins.int
    PATH1_FIELD_NUMBER: builtins.int
    PATH2_FIELD_NUMBER: builtins.int
    headline_part1: typing.Text = ...
    headline_part2: typing.Text = ...
    headline_part3: typing.Text = ...
    description: typing.Text = ...
    description2: typing.Text = ...
    path1: typing.Text = ...
    path2: typing.Text = ...
    def __init__(
        self,
        *,
        headline_part1: typing.Text = ...,
        headline_part2: typing.Text = ...,
        headline_part3: typing.Text = ...,
        description: typing.Text = ...,
        description2: typing.Text = ...,
        path1: typing.Text = ...,
        path2: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_description2",
            b"_description2",
            "_headline_part1",
            b"_headline_part1",
            "_headline_part2",
            b"_headline_part2",
            "_headline_part3",
            b"_headline_part3",
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "description",
            b"description",
            "description2",
            b"description2",
            "headline_part1",
            b"headline_part1",
            "headline_part2",
            b"headline_part2",
            "headline_part3",
            b"headline_part3",
            "path1",
            b"path1",
            "path2",
            b"path2",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_description2",
            b"_description2",
            "_headline_part1",
            b"_headline_part1",
            "_headline_part2",
            b"_headline_part2",
            "_headline_part3",
            b"_headline_part3",
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "description",
            b"description",
            "description2",
            b"description2",
            "headline_part1",
            b"headline_part1",
            "headline_part2",
            b"headline_part2",
            "headline_part3",
            b"headline_part3",
            "path1",
            b"path1",
            "path2",
            b"path2",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description", b"_description"]
    ) -> typing_extensions.Literal["description"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description2", b"_description2"]
    ) -> typing_extensions.Literal["description2"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_headline_part1", b"_headline_part1"],
    ) -> typing_extensions.Literal["headline_part1"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_headline_part2", b"_headline_part2"],
    ) -> typing_extensions.Literal["headline_part2"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_headline_part3", b"_headline_part3"],
    ) -> typing_extensions.Literal["headline_part3"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_path1", b"_path1"]
    ) -> typing_extensions.Literal["path1"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_path2", b"_path2"]
    ) -> typing_extensions.Literal["path2"]: ...

global___ExpandedTextAdInfo = ExpandedTextAdInfo

class CallOnlyAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    PHONE_NUMBER_FIELD_NUMBER: builtins.int
    BUSINESS_NAME_FIELD_NUMBER: builtins.int
    HEADLINE1_FIELD_NUMBER: builtins.int
    HEADLINE2_FIELD_NUMBER: builtins.int
    DESCRIPTION1_FIELD_NUMBER: builtins.int
    DESCRIPTION2_FIELD_NUMBER: builtins.int
    CALL_TRACKED_FIELD_NUMBER: builtins.int
    DISABLE_CALL_CONVERSION_FIELD_NUMBER: builtins.int
    PHONE_NUMBER_VERIFICATION_URL_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_FIELD_NUMBER: builtins.int
    CONVERSION_REPORTING_STATE_FIELD_NUMBER: builtins.int
    country_code: typing.Text = ...
    phone_number: typing.Text = ...
    business_name: typing.Text = ...
    headline1: typing.Text = ...
    headline2: typing.Text = ...
    description1: typing.Text = ...
    description2: typing.Text = ...
    call_tracked: builtins.bool = ...
    disable_call_conversion: builtins.bool = ...
    phone_number_verification_url: typing.Text = ...
    conversion_action: typing.Text = ...
    conversion_reporting_state: google.ads.google_ads.v6.proto.enums.call_conversion_reporting_state_pb2.CallConversionReportingStateEnum.CallConversionReportingState.V = (
        ...
    )
    def __init__(
        self,
        *,
        country_code: typing.Text = ...,
        phone_number: typing.Text = ...,
        business_name: typing.Text = ...,
        headline1: typing.Text = ...,
        headline2: typing.Text = ...,
        description1: typing.Text = ...,
        description2: typing.Text = ...,
        call_tracked: builtins.bool = ...,
        disable_call_conversion: builtins.bool = ...,
        phone_number_verification_url: typing.Text = ...,
        conversion_action: typing.Text = ...,
        conversion_reporting_state: google.ads.google_ads.v6.proto.enums.call_conversion_reporting_state_pb2.CallConversionReportingStateEnum.CallConversionReportingState.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_business_name",
            b"_business_name",
            "_call_tracked",
            b"_call_tracked",
            "_conversion_action",
            b"_conversion_action",
            "_country_code",
            b"_country_code",
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_disable_call_conversion",
            b"_disable_call_conversion",
            "_headline1",
            b"_headline1",
            "_headline2",
            b"_headline2",
            "_phone_number",
            b"_phone_number",
            "_phone_number_verification_url",
            b"_phone_number_verification_url",
            "business_name",
            b"business_name",
            "call_tracked",
            b"call_tracked",
            "conversion_action",
            b"conversion_action",
            "country_code",
            b"country_code",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "disable_call_conversion",
            b"disable_call_conversion",
            "headline1",
            b"headline1",
            "headline2",
            b"headline2",
            "phone_number",
            b"phone_number",
            "phone_number_verification_url",
            b"phone_number_verification_url",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_business_name",
            b"_business_name",
            "_call_tracked",
            b"_call_tracked",
            "_conversion_action",
            b"_conversion_action",
            "_country_code",
            b"_country_code",
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_disable_call_conversion",
            b"_disable_call_conversion",
            "_headline1",
            b"_headline1",
            "_headline2",
            b"_headline2",
            "_phone_number",
            b"_phone_number",
            "_phone_number_verification_url",
            b"_phone_number_verification_url",
            "business_name",
            b"business_name",
            "call_tracked",
            b"call_tracked",
            "conversion_action",
            b"conversion_action",
            "conversion_reporting_state",
            b"conversion_reporting_state",
            "country_code",
            b"country_code",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "disable_call_conversion",
            b"disable_call_conversion",
            "headline1",
            b"headline1",
            "headline2",
            b"headline2",
            "phone_number",
            b"phone_number",
            "phone_number_verification_url",
            b"phone_number_verification_url",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_business_name", b"_business_name"],
    ) -> typing_extensions.Literal["business_name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_call_tracked", b"_call_tracked"]
    ) -> typing_extensions.Literal["call_tracked"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_action", b"_conversion_action"
        ],
    ) -> typing_extensions.Literal["conversion_action"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_country_code", b"_country_code"]
    ) -> typing_extensions.Literal["country_code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description1", b"_description1"]
    ) -> typing_extensions.Literal["description1"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description2", b"_description2"]
    ) -> typing_extensions.Literal["description2"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_disable_call_conversion", b"_disable_call_conversion"
        ],
    ) -> typing_extensions.Literal["disable_call_conversion"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_headline1", b"_headline1"]
    ) -> typing_extensions.Literal["headline1"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_headline2", b"_headline2"]
    ) -> typing_extensions.Literal["headline2"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_phone_number", b"_phone_number"]
    ) -> typing_extensions.Literal["phone_number"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_phone_number_verification_url", b"_phone_number_verification_url"
        ],
    ) -> typing_extensions.Literal["phone_number_verification_url"]: ...

global___CallOnlyAdInfo = CallOnlyAdInfo

class ExpandedDynamicSearchAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DESCRIPTION2_FIELD_NUMBER: builtins.int
    description: typing.Text = ...
    description2: typing.Text = ...
    def __init__(
        self,
        *,
        description: typing.Text = ...,
        description2: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_description2",
            b"_description2",
            "description",
            b"description",
            "description2",
            b"description2",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_description2",
            b"_description2",
            "description",
            b"description",
            "description2",
            b"description2",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description", b"_description"]
    ) -> typing_extensions.Literal["description"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description2", b"_description2"]
    ) -> typing_extensions.Literal["description2"]: ...

global___ExpandedDynamicSearchAdInfo = ExpandedDynamicSearchAdInfo

class HotelAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___HotelAdInfo = HotelAdInfo

class ShoppingSmartAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___ShoppingSmartAdInfo = ShoppingSmartAdInfo

class ShoppingProductAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___ShoppingProductAdInfo = ShoppingProductAdInfo

class ShoppingComparisonListingAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINE_FIELD_NUMBER: builtins.int
    headline: typing.Text = ...
    def __init__(
        self,
        *,
        headline: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_headline", b"_headline", "headline", b"headline"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_headline", b"_headline", "headline", b"headline"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_headline", b"_headline"]
    ) -> typing_extensions.Literal["headline"]: ...

global___ShoppingComparisonListingAdInfo = ShoppingComparisonListingAdInfo

class GmailAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEASER_FIELD_NUMBER: builtins.int
    HEADER_IMAGE_FIELD_NUMBER: builtins.int
    MARKETING_IMAGE_FIELD_NUMBER: builtins.int
    MARKETING_IMAGE_HEADLINE_FIELD_NUMBER: builtins.int
    MARKETING_IMAGE_DESCRIPTION_FIELD_NUMBER: builtins.int
    MARKETING_IMAGE_DISPLAY_CALL_TO_ACTION_FIELD_NUMBER: builtins.int
    PRODUCT_IMAGES_FIELD_NUMBER: builtins.int
    PRODUCT_VIDEOS_FIELD_NUMBER: builtins.int
    header_image: typing.Text = ...
    marketing_image: typing.Text = ...
    marketing_image_headline: typing.Text = ...
    marketing_image_description: typing.Text = ...
    @property
    def teaser(self) -> global___GmailTeaser: ...
    @property
    def marketing_image_display_call_to_action(
        self,
    ) -> global___DisplayCallToAction: ...
    @property
    def product_images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ProductImage
    ]: ...
    @property
    def product_videos(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ProductVideo
    ]: ...
    def __init__(
        self,
        *,
        teaser: typing.Optional[global___GmailTeaser] = ...,
        header_image: typing.Text = ...,
        marketing_image: typing.Text = ...,
        marketing_image_headline: typing.Text = ...,
        marketing_image_description: typing.Text = ...,
        marketing_image_display_call_to_action: typing.Optional[
            global___DisplayCallToAction
        ] = ...,
        product_images: typing.Optional[typing.Iterable[global___ProductImage]] = ...,
        product_videos: typing.Optional[typing.Iterable[global___ProductVideo]] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_header_image",
            b"_header_image",
            "_marketing_image",
            b"_marketing_image",
            "_marketing_image_description",
            b"_marketing_image_description",
            "_marketing_image_headline",
            b"_marketing_image_headline",
            "header_image",
            b"header_image",
            "marketing_image",
            b"marketing_image",
            "marketing_image_description",
            b"marketing_image_description",
            "marketing_image_display_call_to_action",
            b"marketing_image_display_call_to_action",
            "marketing_image_headline",
            b"marketing_image_headline",
            "teaser",
            b"teaser",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_header_image",
            b"_header_image",
            "_marketing_image",
            b"_marketing_image",
            "_marketing_image_description",
            b"_marketing_image_description",
            "_marketing_image_headline",
            b"_marketing_image_headline",
            "header_image",
            b"header_image",
            "marketing_image",
            b"marketing_image",
            "marketing_image_description",
            b"marketing_image_description",
            "marketing_image_display_call_to_action",
            b"marketing_image_display_call_to_action",
            "marketing_image_headline",
            b"marketing_image_headline",
            "product_images",
            b"product_images",
            "product_videos",
            b"product_videos",
            "teaser",
            b"teaser",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_header_image", b"_header_image"]
    ) -> typing_extensions.Literal["header_image"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_marketing_image", b"_marketing_image"],
    ) -> typing_extensions.Literal["marketing_image"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_marketing_image_description", b"_marketing_image_description"
        ],
    ) -> typing_extensions.Literal["marketing_image_description"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_marketing_image_headline", b"_marketing_image_headline"
        ],
    ) -> typing_extensions.Literal["marketing_image_headline"]: ...

global___GmailAdInfo = GmailAdInfo

class GmailTeaser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    BUSINESS_NAME_FIELD_NUMBER: builtins.int
    LOGO_IMAGE_FIELD_NUMBER: builtins.int
    headline: typing.Text = ...
    description: typing.Text = ...
    business_name: typing.Text = ...
    logo_image: typing.Text = ...
    def __init__(
        self,
        *,
        headline: typing.Text = ...,
        description: typing.Text = ...,
        business_name: typing.Text = ...,
        logo_image: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_business_name",
            b"_business_name",
            "_description",
            b"_description",
            "_headline",
            b"_headline",
            "_logo_image",
            b"_logo_image",
            "business_name",
            b"business_name",
            "description",
            b"description",
            "headline",
            b"headline",
            "logo_image",
            b"logo_image",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_business_name",
            b"_business_name",
            "_description",
            b"_description",
            "_headline",
            b"_headline",
            "_logo_image",
            b"_logo_image",
            "business_name",
            b"business_name",
            "description",
            b"description",
            "headline",
            b"headline",
            "logo_image",
            b"logo_image",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_business_name", b"_business_name"],
    ) -> typing_extensions.Literal["business_name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description", b"_description"]
    ) -> typing_extensions.Literal["description"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_headline", b"_headline"]
    ) -> typing_extensions.Literal["headline"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_logo_image", b"_logo_image"]
    ) -> typing_extensions.Literal["logo_image"]: ...

global___GmailTeaser = GmailTeaser

class DisplayCallToAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    URL_COLLECTION_ID_FIELD_NUMBER: builtins.int
    text: typing.Text = ...
    text_color: typing.Text = ...
    url_collection_id: typing.Text = ...
    def __init__(
        self,
        *,
        text: typing.Text = ...,
        text_color: typing.Text = ...,
        url_collection_id: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_text",
            b"_text",
            "_text_color",
            b"_text_color",
            "_url_collection_id",
            b"_url_collection_id",
            "text",
            b"text",
            "text_color",
            b"text_color",
            "url_collection_id",
            b"url_collection_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_text",
            b"_text",
            "_text_color",
            b"_text_color",
            "_url_collection_id",
            b"_url_collection_id",
            "text",
            b"text",
            "text_color",
            b"text_color",
            "url_collection_id",
            b"url_collection_id",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_text", b"_text"]
    ) -> typing_extensions.Literal["text"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_text_color", b"_text_color"]
    ) -> typing_extensions.Literal["text_color"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_url_collection_id", b"_url_collection_id"
        ],
    ) -> typing_extensions.Literal["url_collection_id"]: ...

global___DisplayCallToAction = DisplayCallToAction

class ProductImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRODUCT_IMAGE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_CALL_TO_ACTION_FIELD_NUMBER: builtins.int
    product_image: typing.Text = ...
    description: typing.Text = ...
    @property
    def display_call_to_action(self) -> global___DisplayCallToAction: ...
    def __init__(
        self,
        *,
        product_image: typing.Text = ...,
        description: typing.Text = ...,
        display_call_to_action: typing.Optional[global___DisplayCallToAction] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_product_image",
            b"_product_image",
            "description",
            b"description",
            "display_call_to_action",
            b"display_call_to_action",
            "product_image",
            b"product_image",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_product_image",
            b"_product_image",
            "description",
            b"description",
            "display_call_to_action",
            b"display_call_to_action",
            "product_image",
            b"product_image",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description", b"_description"]
    ) -> typing_extensions.Literal["description"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_image", b"_product_image"],
    ) -> typing_extensions.Literal["product_image"]: ...

global___ProductImage = ProductImage

class ProductVideo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRODUCT_VIDEO_FIELD_NUMBER: builtins.int
    product_video: typing.Text = ...
    def __init__(
        self,
        *,
        product_video: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_product_video", b"_product_video", "product_video", b"product_video"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_product_video", b"_product_video", "product_video", b"product_video"
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_video", b"_product_video"],
    ) -> typing_extensions.Literal["product_video"]: ...

global___ProductVideo = ProductVideo

class ImageAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PIXEL_WIDTH_FIELD_NUMBER: builtins.int
    PIXEL_HEIGHT_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    PREVIEW_PIXEL_WIDTH_FIELD_NUMBER: builtins.int
    PREVIEW_PIXEL_HEIGHT_FIELD_NUMBER: builtins.int
    PREVIEW_IMAGE_URL_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MEDIA_FILE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    AD_ID_TO_COPY_IMAGE_FROM_FIELD_NUMBER: builtins.int
    pixel_width: builtins.int = ...
    pixel_height: builtins.int = ...
    image_url: typing.Text = ...
    preview_pixel_width: builtins.int = ...
    preview_pixel_height: builtins.int = ...
    preview_image_url: typing.Text = ...
    mime_type: google.ads.google_ads.v6.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = (
        ...
    )
    name: typing.Text = ...
    media_file: typing.Text = ...
    data: builtins.bytes = ...
    ad_id_to_copy_image_from: builtins.int = ...
    def __init__(
        self,
        *,
        pixel_width: builtins.int = ...,
        pixel_height: builtins.int = ...,
        image_url: typing.Text = ...,
        preview_pixel_width: builtins.int = ...,
        preview_pixel_height: builtins.int = ...,
        preview_image_url: typing.Text = ...,
        mime_type: google.ads.google_ads.v6.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = ...,
        name: typing.Text = ...,
        media_file: typing.Text = ...,
        data: builtins.bytes = ...,
        ad_id_to_copy_image_from: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_image_url",
            b"_image_url",
            "_name",
            b"_name",
            "_pixel_height",
            b"_pixel_height",
            "_pixel_width",
            b"_pixel_width",
            "_preview_image_url",
            b"_preview_image_url",
            "_preview_pixel_height",
            b"_preview_pixel_height",
            "_preview_pixel_width",
            b"_preview_pixel_width",
            "ad_id_to_copy_image_from",
            b"ad_id_to_copy_image_from",
            "data",
            b"data",
            "image",
            b"image",
            "image_url",
            b"image_url",
            "media_file",
            b"media_file",
            "name",
            b"name",
            "pixel_height",
            b"pixel_height",
            "pixel_width",
            b"pixel_width",
            "preview_image_url",
            b"preview_image_url",
            "preview_pixel_height",
            b"preview_pixel_height",
            "preview_pixel_width",
            b"preview_pixel_width",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_image_url",
            b"_image_url",
            "_name",
            b"_name",
            "_pixel_height",
            b"_pixel_height",
            "_pixel_width",
            b"_pixel_width",
            "_preview_image_url",
            b"_preview_image_url",
            "_preview_pixel_height",
            b"_preview_pixel_height",
            "_preview_pixel_width",
            b"_preview_pixel_width",
            "ad_id_to_copy_image_from",
            b"ad_id_to_copy_image_from",
            "data",
            b"data",
            "image",
            b"image",
            "image_url",
            b"image_url",
            "media_file",
            b"media_file",
            "mime_type",
            b"mime_type",
            "name",
            b"name",
            "pixel_height",
            b"pixel_height",
            "pixel_width",
            b"pixel_width",
            "preview_image_url",
            b"preview_image_url",
            "preview_pixel_height",
            b"preview_pixel_height",
            "preview_pixel_width",
            b"preview_pixel_width",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_image_url", b"_image_url"]
    ) -> typing_extensions.Literal["image_url"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_pixel_height", b"_pixel_height"]
    ) -> typing_extensions.Literal["pixel_height"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_pixel_width", b"_pixel_width"]
    ) -> typing_extensions.Literal["pixel_width"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_preview_image_url", b"_preview_image_url"
        ],
    ) -> typing_extensions.Literal["preview_image_url"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_preview_pixel_height", b"_preview_pixel_height"
        ],
    ) -> typing_extensions.Literal["preview_pixel_height"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_preview_pixel_width", b"_preview_pixel_width"
        ],
    ) -> typing_extensions.Literal["preview_pixel_width"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["image", b"image"]
    ) -> typing_extensions.Literal[
        "media_file", "data", "ad_id_to_copy_image_from"
    ]: ...

global___ImageAdInfo = ImageAdInfo

class VideoBumperInStreamAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMPANION_BANNER_FIELD_NUMBER: builtins.int
    companion_banner: typing.Text = ...
    def __init__(
        self,
        *,
        companion_banner: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_companion_banner",
            b"_companion_banner",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_companion_banner",
            b"_companion_banner",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_companion_banner", b"_companion_banner"
        ],
    ) -> typing_extensions.Literal["companion_banner"]: ...

global___VideoBumperInStreamAdInfo = VideoBumperInStreamAdInfo

class VideoNonSkippableInStreamAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMPANION_BANNER_FIELD_NUMBER: builtins.int
    companion_banner: typing.Text = ...
    def __init__(
        self,
        *,
        companion_banner: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_companion_banner",
            b"_companion_banner",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_companion_banner",
            b"_companion_banner",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_companion_banner", b"_companion_banner"
        ],
    ) -> typing_extensions.Literal["companion_banner"]: ...

global___VideoNonSkippableInStreamAdInfo = VideoNonSkippableInStreamAdInfo

class VideoTrueViewInStreamAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ACTION_BUTTON_LABEL_FIELD_NUMBER: builtins.int
    ACTION_HEADLINE_FIELD_NUMBER: builtins.int
    COMPANION_BANNER_FIELD_NUMBER: builtins.int
    action_button_label: typing.Text = ...
    action_headline: typing.Text = ...
    companion_banner: typing.Text = ...
    def __init__(
        self,
        *,
        action_button_label: typing.Text = ...,
        action_headline: typing.Text = ...,
        companion_banner: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_action_button_label",
            b"_action_button_label",
            "_action_headline",
            b"_action_headline",
            "_companion_banner",
            b"_companion_banner",
            "action_button_label",
            b"action_button_label",
            "action_headline",
            b"action_headline",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_action_button_label",
            b"_action_button_label",
            "_action_headline",
            b"_action_headline",
            "_companion_banner",
            b"_companion_banner",
            "action_button_label",
            b"action_button_label",
            "action_headline",
            b"action_headline",
            "companion_banner",
            b"companion_banner",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_action_button_label", b"_action_button_label"
        ],
    ) -> typing_extensions.Literal["action_button_label"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_action_headline", b"_action_headline"],
    ) -> typing_extensions.Literal["action_headline"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_companion_banner", b"_companion_banner"
        ],
    ) -> typing_extensions.Literal["companion_banner"]: ...

global___VideoTrueViewInStreamAdInfo = VideoTrueViewInStreamAdInfo

class VideoOutstreamAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    headline: typing.Text = ...
    description: typing.Text = ...
    def __init__(
        self,
        *,
        headline: typing.Text = ...,
        description: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_headline",
            b"_headline",
            "description",
            b"description",
            "headline",
            b"headline",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_description",
            b"_description",
            "_headline",
            b"_headline",
            "description",
            b"description",
            "headline",
            b"headline",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description", b"_description"]
    ) -> typing_extensions.Literal["description"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_headline", b"_headline"]
    ) -> typing_extensions.Literal["headline"]: ...

global___VideoOutstreamAdInfo = VideoOutstreamAdInfo

class VideoTrueViewDiscoveryAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINE_FIELD_NUMBER: builtins.int
    DESCRIPTION1_FIELD_NUMBER: builtins.int
    DESCRIPTION2_FIELD_NUMBER: builtins.int
    headline: typing.Text = ...
    description1: typing.Text = ...
    description2: typing.Text = ...
    def __init__(
        self,
        *,
        headline: typing.Text = ...,
        description1: typing.Text = ...,
        description2: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description1", b"_description1"]
    ) -> typing_extensions.Literal["description1"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description2", b"_description2"]
    ) -> typing_extensions.Literal["description2"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_headline", b"_headline"]
    ) -> typing_extensions.Literal["headline"]: ...

global___VideoTrueViewDiscoveryAdInfo = VideoTrueViewDiscoveryAdInfo

class VideoAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MEDIA_FILE_FIELD_NUMBER: builtins.int
    IN_STREAM_FIELD_NUMBER: builtins.int
    BUMPER_FIELD_NUMBER: builtins.int
    OUT_STREAM_FIELD_NUMBER: builtins.int
    NON_SKIPPABLE_FIELD_NUMBER: builtins.int
    DISCOVERY_FIELD_NUMBER: builtins.int
    media_file: typing.Text = ...
    @property
    def in_stream(self) -> global___VideoTrueViewInStreamAdInfo: ...
    @property
    def bumper(self) -> global___VideoBumperInStreamAdInfo: ...
    @property
    def out_stream(self) -> global___VideoOutstreamAdInfo: ...
    @property
    def non_skippable(self) -> global___VideoNonSkippableInStreamAdInfo: ...
    @property
    def discovery(self) -> global___VideoTrueViewDiscoveryAdInfo: ...
    def __init__(
        self,
        *,
        media_file: typing.Text = ...,
        in_stream: typing.Optional[global___VideoTrueViewInStreamAdInfo] = ...,
        bumper: typing.Optional[global___VideoBumperInStreamAdInfo] = ...,
        out_stream: typing.Optional[global___VideoOutstreamAdInfo] = ...,
        non_skippable: typing.Optional[global___VideoNonSkippableInStreamAdInfo] = ...,
        discovery: typing.Optional[global___VideoTrueViewDiscoveryAdInfo] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_media_file",
            b"_media_file",
            "bumper",
            b"bumper",
            "discovery",
            b"discovery",
            "format",
            b"format",
            "in_stream",
            b"in_stream",
            "media_file",
            b"media_file",
            "non_skippable",
            b"non_skippable",
            "out_stream",
            b"out_stream",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_media_file",
            b"_media_file",
            "bumper",
            b"bumper",
            "discovery",
            b"discovery",
            "format",
            b"format",
            "in_stream",
            b"in_stream",
            "media_file",
            b"media_file",
            "non_skippable",
            b"non_skippable",
            "out_stream",
            b"out_stream",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_media_file", b"_media_file"]
    ) -> typing_extensions.Literal["media_file"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["format", b"format"]
    ) -> typing_extensions.Literal[
        "in_stream", "bumper", "out_stream", "non_skippable", "discovery"
    ]: ...

global___VideoAdInfo = VideoAdInfo

class VideoResponsiveAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINES_FIELD_NUMBER: builtins.int
    LONG_HEADLINES_FIELD_NUMBER: builtins.int
    DESCRIPTIONS_FIELD_NUMBER: builtins.int
    CALL_TO_ACTIONS_FIELD_NUMBER: builtins.int
    VIDEOS_FIELD_NUMBER: builtins.int
    COMPANION_BANNERS_FIELD_NUMBER: builtins.int
    @property
    def headlines(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def long_headlines(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def descriptions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def call_to_actions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def videos(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
    ]: ...
    @property
    def companion_banners(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    def __init__(
        self,
        *,
        headlines: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        long_headlines: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        descriptions: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        call_to_actions: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        videos: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
            ]
        ] = ...,
        companion_banners: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "call_to_actions",
            b"call_to_actions",
            "companion_banners",
            b"companion_banners",
            "descriptions",
            b"descriptions",
            "headlines",
            b"headlines",
            "long_headlines",
            b"long_headlines",
            "videos",
            b"videos",
        ],
    ) -> None: ...

global___VideoResponsiveAdInfo = VideoResponsiveAdInfo

class ResponsiveSearchAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINES_FIELD_NUMBER: builtins.int
    DESCRIPTIONS_FIELD_NUMBER: builtins.int
    PATH1_FIELD_NUMBER: builtins.int
    PATH2_FIELD_NUMBER: builtins.int
    path1: typing.Text = ...
    path2: typing.Text = ...
    @property
    def headlines(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def descriptions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    def __init__(
        self,
        *,
        headlines: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        descriptions: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        path1: typing.Text = ...,
        path2: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "path1",
            b"path1",
            "path2",
            b"path2",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "descriptions",
            b"descriptions",
            "headlines",
            b"headlines",
            "path1",
            b"path1",
            "path2",
            b"path2",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_path1", b"_path1"]
    ) -> typing_extensions.Literal["path1"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_path2", b"_path2"]
    ) -> typing_extensions.Literal["path2"]: ...

global___ResponsiveSearchAdInfo = ResponsiveSearchAdInfo

class LegacyResponsiveDisplayAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SHORT_HEADLINE_FIELD_NUMBER: builtins.int
    LONG_HEADLINE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    BUSINESS_NAME_FIELD_NUMBER: builtins.int
    ALLOW_FLEXIBLE_COLOR_FIELD_NUMBER: builtins.int
    ACCENT_COLOR_FIELD_NUMBER: builtins.int
    MAIN_COLOR_FIELD_NUMBER: builtins.int
    CALL_TO_ACTION_TEXT_FIELD_NUMBER: builtins.int
    LOGO_IMAGE_FIELD_NUMBER: builtins.int
    SQUARE_LOGO_IMAGE_FIELD_NUMBER: builtins.int
    MARKETING_IMAGE_FIELD_NUMBER: builtins.int
    SQUARE_MARKETING_IMAGE_FIELD_NUMBER: builtins.int
    FORMAT_SETTING_FIELD_NUMBER: builtins.int
    PRICE_PREFIX_FIELD_NUMBER: builtins.int
    PROMO_TEXT_FIELD_NUMBER: builtins.int
    short_headline: typing.Text = ...
    long_headline: typing.Text = ...
    description: typing.Text = ...
    business_name: typing.Text = ...
    allow_flexible_color: builtins.bool = ...
    accent_color: typing.Text = ...
    main_color: typing.Text = ...
    call_to_action_text: typing.Text = ...
    logo_image: typing.Text = ...
    square_logo_image: typing.Text = ...
    marketing_image: typing.Text = ...
    square_marketing_image: typing.Text = ...
    format_setting: google.ads.google_ads.v6.proto.enums.display_ad_format_setting_pb2.DisplayAdFormatSettingEnum.DisplayAdFormatSetting.V = (
        ...
    )
    price_prefix: typing.Text = ...
    promo_text: typing.Text = ...
    def __init__(
        self,
        *,
        short_headline: typing.Text = ...,
        long_headline: typing.Text = ...,
        description: typing.Text = ...,
        business_name: typing.Text = ...,
        allow_flexible_color: builtins.bool = ...,
        accent_color: typing.Text = ...,
        main_color: typing.Text = ...,
        call_to_action_text: typing.Text = ...,
        logo_image: typing.Text = ...,
        square_logo_image: typing.Text = ...,
        marketing_image: typing.Text = ...,
        square_marketing_image: typing.Text = ...,
        format_setting: google.ads.google_ads.v6.proto.enums.display_ad_format_setting_pb2.DisplayAdFormatSettingEnum.DisplayAdFormatSetting.V = ...,
        price_prefix: typing.Text = ...,
        promo_text: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_accent_color",
            b"_accent_color",
            "_allow_flexible_color",
            b"_allow_flexible_color",
            "_business_name",
            b"_business_name",
            "_call_to_action_text",
            b"_call_to_action_text",
            "_description",
            b"_description",
            "_logo_image",
            b"_logo_image",
            "_long_headline",
            b"_long_headline",
            "_main_color",
            b"_main_color",
            "_marketing_image",
            b"_marketing_image",
            "_price_prefix",
            b"_price_prefix",
            "_promo_text",
            b"_promo_text",
            "_short_headline",
            b"_short_headline",
            "_square_logo_image",
            b"_square_logo_image",
            "_square_marketing_image",
            b"_square_marketing_image",
            "accent_color",
            b"accent_color",
            "allow_flexible_color",
            b"allow_flexible_color",
            "business_name",
            b"business_name",
            "call_to_action_text",
            b"call_to_action_text",
            "description",
            b"description",
            "logo_image",
            b"logo_image",
            "long_headline",
            b"long_headline",
            "main_color",
            b"main_color",
            "marketing_image",
            b"marketing_image",
            "price_prefix",
            b"price_prefix",
            "promo_text",
            b"promo_text",
            "short_headline",
            b"short_headline",
            "square_logo_image",
            b"square_logo_image",
            "square_marketing_image",
            b"square_marketing_image",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_accent_color",
            b"_accent_color",
            "_allow_flexible_color",
            b"_allow_flexible_color",
            "_business_name",
            b"_business_name",
            "_call_to_action_text",
            b"_call_to_action_text",
            "_description",
            b"_description",
            "_logo_image",
            b"_logo_image",
            "_long_headline",
            b"_long_headline",
            "_main_color",
            b"_main_color",
            "_marketing_image",
            b"_marketing_image",
            "_price_prefix",
            b"_price_prefix",
            "_promo_text",
            b"_promo_text",
            "_short_headline",
            b"_short_headline",
            "_square_logo_image",
            b"_square_logo_image",
            "_square_marketing_image",
            b"_square_marketing_image",
            "accent_color",
            b"accent_color",
            "allow_flexible_color",
            b"allow_flexible_color",
            "business_name",
            b"business_name",
            "call_to_action_text",
            b"call_to_action_text",
            "description",
            b"description",
            "format_setting",
            b"format_setting",
            "logo_image",
            b"logo_image",
            "long_headline",
            b"long_headline",
            "main_color",
            b"main_color",
            "marketing_image",
            b"marketing_image",
            "price_prefix",
            b"price_prefix",
            "promo_text",
            b"promo_text",
            "short_headline",
            b"short_headline",
            "square_logo_image",
            b"square_logo_image",
            "square_marketing_image",
            b"square_marketing_image",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_accent_color", b"_accent_color"]
    ) -> typing_extensions.Literal["accent_color"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_allow_flexible_color", b"_allow_flexible_color"
        ],
    ) -> typing_extensions.Literal["allow_flexible_color"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_business_name", b"_business_name"],
    ) -> typing_extensions.Literal["business_name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_call_to_action_text", b"_call_to_action_text"
        ],
    ) -> typing_extensions.Literal["call_to_action_text"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description", b"_description"]
    ) -> typing_extensions.Literal["description"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_logo_image", b"_logo_image"]
    ) -> typing_extensions.Literal["logo_image"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_long_headline", b"_long_headline"],
    ) -> typing_extensions.Literal["long_headline"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_main_color", b"_main_color"]
    ) -> typing_extensions.Literal["main_color"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_marketing_image", b"_marketing_image"],
    ) -> typing_extensions.Literal["marketing_image"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_price_prefix", b"_price_prefix"]
    ) -> typing_extensions.Literal["price_prefix"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_promo_text", b"_promo_text"]
    ) -> typing_extensions.Literal["promo_text"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_short_headline", b"_short_headline"],
    ) -> typing_extensions.Literal["short_headline"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_square_logo_image", b"_square_logo_image"
        ],
    ) -> typing_extensions.Literal["square_logo_image"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_square_marketing_image", b"_square_marketing_image"
        ],
    ) -> typing_extensions.Literal["square_marketing_image"]: ...

global___LegacyResponsiveDisplayAdInfo = LegacyResponsiveDisplayAdInfo

class AppAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MANDATORY_AD_TEXT_FIELD_NUMBER: builtins.int
    HEADLINES_FIELD_NUMBER: builtins.int
    DESCRIPTIONS_FIELD_NUMBER: builtins.int
    IMAGES_FIELD_NUMBER: builtins.int
    YOUTUBE_VIDEOS_FIELD_NUMBER: builtins.int
    HTML5_MEDIA_BUNDLES_FIELD_NUMBER: builtins.int
    @property
    def mandatory_ad_text(
        self,
    ) -> google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset: ...
    @property
    def headlines(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def descriptions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    @property
    def youtube_videos(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
    ]: ...
    @property
    def html5_media_bundles(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdMediaBundleAsset
    ]: ...
    def __init__(
        self,
        *,
        mandatory_ad_text: typing.Optional[
            google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
        ] = ...,
        headlines: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        descriptions: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        images: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
        youtube_videos: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
            ]
        ] = ...,
        html5_media_bundles: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdMediaBundleAsset
            ]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "mandatory_ad_text", b"mandatory_ad_text"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "descriptions",
            b"descriptions",
            "headlines",
            b"headlines",
            "html5_media_bundles",
            b"html5_media_bundles",
            "images",
            b"images",
            "mandatory_ad_text",
            b"mandatory_ad_text",
            "youtube_videos",
            b"youtube_videos",
        ],
    ) -> None: ...

global___AppAdInfo = AppAdInfo

class AppEngagementAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINES_FIELD_NUMBER: builtins.int
    DESCRIPTIONS_FIELD_NUMBER: builtins.int
    IMAGES_FIELD_NUMBER: builtins.int
    VIDEOS_FIELD_NUMBER: builtins.int
    @property
    def headlines(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def descriptions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    @property
    def videos(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
    ]: ...
    def __init__(
        self,
        *,
        headlines: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        descriptions: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        images: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
        videos: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
            ]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "descriptions",
            b"descriptions",
            "headlines",
            b"headlines",
            "images",
            b"images",
            "videos",
            b"videos",
        ],
    ) -> None: ...

global___AppEngagementAdInfo = AppEngagementAdInfo

class LegacyAppInstallAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    APP_ID_FIELD_NUMBER: builtins.int
    APP_STORE_FIELD_NUMBER: builtins.int
    HEADLINE_FIELD_NUMBER: builtins.int
    DESCRIPTION1_FIELD_NUMBER: builtins.int
    DESCRIPTION2_FIELD_NUMBER: builtins.int
    app_id: typing.Text = ...
    app_store: google.ads.google_ads.v6.proto.enums.legacy_app_install_ad_app_store_pb2.LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V = (
        ...
    )
    headline: typing.Text = ...
    description1: typing.Text = ...
    description2: typing.Text = ...
    def __init__(
        self,
        *,
        app_id: typing.Text = ...,
        app_store: google.ads.google_ads.v6.proto.enums.legacy_app_install_ad_app_store_pb2.LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore.V = ...,
        headline: typing.Text = ...,
        description1: typing.Text = ...,
        description2: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_app_id",
            b"_app_id",
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "app_id",
            b"app_id",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_app_id",
            b"_app_id",
            "_description1",
            b"_description1",
            "_description2",
            b"_description2",
            "_headline",
            b"_headline",
            "app_id",
            b"app_id",
            "app_store",
            b"app_store",
            "description1",
            b"description1",
            "description2",
            b"description2",
            "headline",
            b"headline",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_app_id", b"_app_id"]
    ) -> typing_extensions.Literal["app_id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description1", b"_description1"]
    ) -> typing_extensions.Literal["description1"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_description2", b"_description2"]
    ) -> typing_extensions.Literal["description2"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_headline", b"_headline"]
    ) -> typing_extensions.Literal["headline"]: ...

global___LegacyAppInstallAdInfo = LegacyAppInstallAdInfo

class ResponsiveDisplayAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MARKETING_IMAGES_FIELD_NUMBER: builtins.int
    SQUARE_MARKETING_IMAGES_FIELD_NUMBER: builtins.int
    LOGO_IMAGES_FIELD_NUMBER: builtins.int
    SQUARE_LOGO_IMAGES_FIELD_NUMBER: builtins.int
    HEADLINES_FIELD_NUMBER: builtins.int
    LONG_HEADLINE_FIELD_NUMBER: builtins.int
    DESCRIPTIONS_FIELD_NUMBER: builtins.int
    YOUTUBE_VIDEOS_FIELD_NUMBER: builtins.int
    BUSINESS_NAME_FIELD_NUMBER: builtins.int
    MAIN_COLOR_FIELD_NUMBER: builtins.int
    ACCENT_COLOR_FIELD_NUMBER: builtins.int
    ALLOW_FLEXIBLE_COLOR_FIELD_NUMBER: builtins.int
    CALL_TO_ACTION_TEXT_FIELD_NUMBER: builtins.int
    PRICE_PREFIX_FIELD_NUMBER: builtins.int
    PROMO_TEXT_FIELD_NUMBER: builtins.int
    FORMAT_SETTING_FIELD_NUMBER: builtins.int
    CONTROL_SPEC_FIELD_NUMBER: builtins.int
    business_name: typing.Text = ...
    main_color: typing.Text = ...
    accent_color: typing.Text = ...
    allow_flexible_color: builtins.bool = ...
    call_to_action_text: typing.Text = ...
    price_prefix: typing.Text = ...
    promo_text: typing.Text = ...
    format_setting: google.ads.google_ads.v6.proto.enums.display_ad_format_setting_pb2.DisplayAdFormatSettingEnum.DisplayAdFormatSetting.V = (
        ...
    )
    @property
    def marketing_images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    @property
    def square_marketing_images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    @property
    def logo_images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    @property
    def square_logo_images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    @property
    def headlines(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def long_headline(
        self,
    ) -> google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset: ...
    @property
    def descriptions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def youtube_videos(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
    ]: ...
    @property
    def control_spec(self) -> global___ResponsiveDisplayAdControlSpec: ...
    def __init__(
        self,
        *,
        marketing_images: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
        square_marketing_images: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
        logo_images: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
        square_logo_images: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
        headlines: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        long_headline: typing.Optional[
            google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
        ] = ...,
        descriptions: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        youtube_videos: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
            ]
        ] = ...,
        business_name: typing.Text = ...,
        main_color: typing.Text = ...,
        accent_color: typing.Text = ...,
        allow_flexible_color: builtins.bool = ...,
        call_to_action_text: typing.Text = ...,
        price_prefix: typing.Text = ...,
        promo_text: typing.Text = ...,
        format_setting: google.ads.google_ads.v6.proto.enums.display_ad_format_setting_pb2.DisplayAdFormatSettingEnum.DisplayAdFormatSetting.V = ...,
        control_spec: typing.Optional[global___ResponsiveDisplayAdControlSpec] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_accent_color",
            b"_accent_color",
            "_allow_flexible_color",
            b"_allow_flexible_color",
            "_business_name",
            b"_business_name",
            "_call_to_action_text",
            b"_call_to_action_text",
            "_main_color",
            b"_main_color",
            "_price_prefix",
            b"_price_prefix",
            "_promo_text",
            b"_promo_text",
            "accent_color",
            b"accent_color",
            "allow_flexible_color",
            b"allow_flexible_color",
            "business_name",
            b"business_name",
            "call_to_action_text",
            b"call_to_action_text",
            "control_spec",
            b"control_spec",
            "long_headline",
            b"long_headline",
            "main_color",
            b"main_color",
            "price_prefix",
            b"price_prefix",
            "promo_text",
            b"promo_text",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_accent_color",
            b"_accent_color",
            "_allow_flexible_color",
            b"_allow_flexible_color",
            "_business_name",
            b"_business_name",
            "_call_to_action_text",
            b"_call_to_action_text",
            "_main_color",
            b"_main_color",
            "_price_prefix",
            b"_price_prefix",
            "_promo_text",
            b"_promo_text",
            "accent_color",
            b"accent_color",
            "allow_flexible_color",
            b"allow_flexible_color",
            "business_name",
            b"business_name",
            "call_to_action_text",
            b"call_to_action_text",
            "control_spec",
            b"control_spec",
            "descriptions",
            b"descriptions",
            "format_setting",
            b"format_setting",
            "headlines",
            b"headlines",
            "logo_images",
            b"logo_images",
            "long_headline",
            b"long_headline",
            "main_color",
            b"main_color",
            "marketing_images",
            b"marketing_images",
            "price_prefix",
            b"price_prefix",
            "promo_text",
            b"promo_text",
            "square_logo_images",
            b"square_logo_images",
            "square_marketing_images",
            b"square_marketing_images",
            "youtube_videos",
            b"youtube_videos",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_accent_color", b"_accent_color"]
    ) -> typing_extensions.Literal["accent_color"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_allow_flexible_color", b"_allow_flexible_color"
        ],
    ) -> typing_extensions.Literal["allow_flexible_color"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_business_name", b"_business_name"],
    ) -> typing_extensions.Literal["business_name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_call_to_action_text", b"_call_to_action_text"
        ],
    ) -> typing_extensions.Literal["call_to_action_text"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_main_color", b"_main_color"]
    ) -> typing_extensions.Literal["main_color"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_price_prefix", b"_price_prefix"]
    ) -> typing_extensions.Literal["price_prefix"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_promo_text", b"_promo_text"]
    ) -> typing_extensions.Literal["promo_text"]: ...

global___ResponsiveDisplayAdInfo = ResponsiveDisplayAdInfo

class LocalAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADLINES_FIELD_NUMBER: builtins.int
    DESCRIPTIONS_FIELD_NUMBER: builtins.int
    CALL_TO_ACTIONS_FIELD_NUMBER: builtins.int
    MARKETING_IMAGES_FIELD_NUMBER: builtins.int
    LOGO_IMAGES_FIELD_NUMBER: builtins.int
    VIDEOS_FIELD_NUMBER: builtins.int
    PATH1_FIELD_NUMBER: builtins.int
    PATH2_FIELD_NUMBER: builtins.int
    path1: typing.Text = ...
    path2: typing.Text = ...
    @property
    def headlines(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def descriptions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def call_to_actions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
    ]: ...
    @property
    def marketing_images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    @property
    def logo_images(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
    ]: ...
    @property
    def videos(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
    ]: ...
    def __init__(
        self,
        *,
        headlines: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        descriptions: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        call_to_actions: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdTextAsset
            ]
        ] = ...,
        marketing_images: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
        logo_images: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdImageAsset
            ]
        ] = ...,
        videos: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdVideoAsset
            ]
        ] = ...,
        path1: typing.Text = ...,
        path2: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "path1",
            b"path1",
            "path2",
            b"path2",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_path1",
            b"_path1",
            "_path2",
            b"_path2",
            "call_to_actions",
            b"call_to_actions",
            "descriptions",
            b"descriptions",
            "headlines",
            b"headlines",
            "logo_images",
            b"logo_images",
            "marketing_images",
            b"marketing_images",
            "path1",
            b"path1",
            "path2",
            b"path2",
            "videos",
            b"videos",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_path1", b"_path1"]
    ) -> typing_extensions.Literal["path1"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_path2", b"_path2"]
    ) -> typing_extensions.Literal["path2"]: ...

global___LocalAdInfo = LocalAdInfo

class DisplayUploadAdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DISPLAY_UPLOAD_PRODUCT_TYPE_FIELD_NUMBER: builtins.int
    MEDIA_BUNDLE_FIELD_NUMBER: builtins.int
    display_upload_product_type: google.ads.google_ads.v6.proto.enums.display_upload_product_type_pb2.DisplayUploadProductTypeEnum.DisplayUploadProductType.V = (
        ...
    )
    @property
    def media_bundle(
        self,
    ) -> google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdMediaBundleAsset: ...
    def __init__(
        self,
        *,
        display_upload_product_type: google.ads.google_ads.v6.proto.enums.display_upload_product_type_pb2.DisplayUploadProductTypeEnum.DisplayUploadProductType.V = ...,
        media_bundle: typing.Optional[
            google.ads.google_ads.v6.proto.common.ad_asset_pb2.AdMediaBundleAsset
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "media_asset", b"media_asset", "media_bundle", b"media_bundle"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "display_upload_product_type",
            b"display_upload_product_type",
            "media_asset",
            b"media_asset",
            "media_bundle",
            b"media_bundle",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["media_asset", b"media_asset"]
    ) -> typing_extensions.Literal["media_bundle"]: ...

global___DisplayUploadAdInfo = DisplayUploadAdInfo

class ResponsiveDisplayAdControlSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ENABLE_ASSET_ENHANCEMENTS_FIELD_NUMBER: builtins.int
    ENABLE_AUTOGEN_VIDEO_FIELD_NUMBER: builtins.int
    enable_asset_enhancements: builtins.bool = ...
    enable_autogen_video: builtins.bool = ...
    def __init__(
        self,
        *,
        enable_asset_enhancements: builtins.bool = ...,
        enable_autogen_video: builtins.bool = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "enable_asset_enhancements",
            b"enable_asset_enhancements",
            "enable_autogen_video",
            b"enable_autogen_video",
        ],
    ) -> None: ...

global___ResponsiveDisplayAdControlSpec = ResponsiveDisplayAdControlSpec



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AppCampaignAppStoreEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AppCampaignAppStore(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AppCampaignAppStore.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AppCampaignAppStoreEnum.AppCampaignAppStore.V(0)
        UNKNOWN = AppCampaignAppStoreEnum.AppCampaignAppStore.V(1)
        APPLE_APP_STORE = AppCampaignAppStoreEnum.AppCampaignAppStore.V(2)
        GOOGLE_APP_STORE = AppCampaignAppStoreEnum.AppCampaignAppStore.V(3)
    class AppCampaignAppStore(metaclass=_AppCampaignAppStore):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AppCampaignAppStoreEnum.AppCampaignAppStore.V(0)
    UNKNOWN = AppCampaignAppStoreEnum.AppCampaignAppStore.V(1)
    APPLE_APP_STORE = AppCampaignAppStoreEnum.AppCampaignAppStore.V(2)
    GOOGLE_APP_STORE = AppCampaignAppStoreEnum.AppCampaignAppStore.V(3)
    def __init__(
        self,
    ) -> None: ...

global___AppCampaignAppStoreEnum = AppCampaignAppStoreEnum
